# Change Log
All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](http://semver.org/).

The format is based on [Keep a Changelog](http://keepachangelog.com/).


## 3.0.0 - 2017-11-16

### Changed
 - Improved JSON logging
 - Simplified integration with Flask applications
 - Simplified integration with Sanic applications
 - Cleanup for open-sourcing
